@@ -1,8 +1,6 @@
 # pylint: disable=invalid-name
-"""
-Simulation environment.
+"""Simulation environment."""
 
-"""
 import numpy as np
 from scipy.integrate import solve_ivp
 from scipy.io import savemat
@@ -17,21 +15,21 @@ class Delay:
 
     This models the computational delay as a ring buffer.
 
+    Parameters
+    ----------
+    length : int, optional
+        Length of the buffer in samples. The default is 1.
+
     """
 
-    # pylint: disable=R0903
+    # pylint: disable=too-few-public-methods
     def __init__(self, length=1, elem=3):
-        """
-        Parameters
-        ----------
-        length : int, optional
-            Length of the buffer in samples. The default is 1.
-
-        """
         self.data = length*[elem*[0]]  # Creates a zero list
 
     def __call__(self, u):
         """
+        Delay the input.
+
         Parameters
         ----------
         u : array_like, shape (elem,)
@@ -56,31 +54,70 @@ class CarrierCmp:
 
     This computes the the switching states and their durations based on the
     duty ratios. Instead of searching for zero crossings, the switching
-    instants are explicilty computed in the begininning of each sampling
-    period, allowing faster simulations.
+    instants are explicitly computed in the beginning of each sampling period,
+    allowing faster simulations.
+
+    Parameters
+    ----------
+    N : int, optional
+        Amount of the counter quantization levels. The default is 2**12.
+    return_complex : bool, optional
+        Complex switching state space vectors are returned if True. Otherwise
+        phase switching states are returned. The default is True.
+
+    Examples
+    --------
+    >>> from motulator.simulation import CarrierCmp
+    >>> carrier_cmp = CarrierCmp(return_complex=False)
+    >>> # First call gives rising edges
+    >>> t_steps, q_abc = carrier_cmp(1e-3, [.4, .2, .8])
+    >>> # Durations of the switching states
+    >>> t_steps
+    array([0.00019995, 0.00040015, 0.00019995, 0.00019995])
+    >>> # Switching states
+    >>> q_abc
+    array([[0, 0, 0],
+           [0, 0, 1],
+           [1, 0, 1],
+           [1, 1, 1]])
+    >>> # Second call gives falling edges
+    >>> t_steps, q_abc = carrier_cmp(.001, [.4, .2, .8])
+    >>> t_steps
+    array([0.00019995, 0.00019995, 0.00040015, 0.00019995])
+    >>> q_abc
+    array([[1, 1, 1],
+           [1, 0, 1],
+           [0, 0, 1],
+           [0, 0, 0]])
+    >>> # Sum of the step times equals T_s
+    >>> np.sum(t_steps)
+    0.001
+    >>> # 50% duty ratios in all phases
+    >>> t_steps, q_abc = carrier_cmp(1e-3, [.5, .5, .5])
+    >>> t_steps
+    array([0.0005, 0.    , 0.    , 0.0005])
+    >>> q_abc
+    array([[0, 0, 0],
+           [0, 0, 0],
+           [0, 0, 0],
+           [1, 1, 1]])
 
     """
+
     # pylint: disable=too-few-public-methods
-
-    def __init__(self, N=2**12):
-        """
-        Parameters
-        ----------
-        N : int, optional
-            Amount of the counter quantization levels. The default is 2**12.
-
-        """
+    def __init__(self, N=2**12, return_complex=True):
         self.N = N
+        self.return_complex = return_complex
         self.rising_edge = True  # Stores the carrier direction
 
     def __call__(self, T_s, d_abc):
         """
-        Carrier comparison.
+        Compute the switching state durations and vectors.
 
         Parameters
         ----------
         T_s : float
-            Sampling period (either half or full carrier period).
+            Half carrier period.
         d_abc : array_like of floats, shape (3,)
             Duty ratios in the range [0, 1].
 
@@ -89,36 +126,36 @@ class CarrierCmp:
         t_steps : ndarray, shape (4,)
             Switching state durations, `[t0, t1, t2, t3]`.
         q : complex ndarray, shape (4,)
-            Switching state vectors, `[0, q1, q2, 0]`, where `q1` and `q2` are
-            active vectors.
+            Switching state vectors, `[q0, q1, q2, q3]`, where `q1` and `q2`
+            are active vectors.
+
+        Notes
+        -----
+        No switching (e.g. `d_a == 0` or `d_a == 1`) or simultaneous switchings
+        (e.g. `d_a == d_b`) lead to zeroes in `t_steps`.
 
         """
         # Quantize the duty ratios to N levels
         d_abc = np.round(self.N*np.asarray(d_abc))/self.N
 
-        # Normalized switching instants and switching states
-        if self.rising_edge:
-            # Normalized switching instants: t_n = [0, t_n1, t_n2, t_n3]
-            t_n = np.append(0, np.sort(1 - d_abc))
-            # States: q_abc = [[0, 0, 0], [q_abc1], [q_abc2], [1, 1, 1]]
-            q_abc = (t_n[:, np.newaxis] >= 1 - d_abc).astype(int)
-        else:
-            t_n = np.append(0, np.sort(d_abc))
-            q_abc = (t_n[:, np.newaxis] < d_abc).astype(int)
+        # Assume falling edge and compute the normalized switching instants:
+        t_n = np.append(0, np.sort(d_abc))
+        # Compute the correponding switching states:
+        q_abc = (t_n[:, np.newaxis] < d_abc).astype(int)
 
-        # Durations of switching states: t_steps = [t0, t1, t2, t3]
+        # Durations of switching states
         t_steps = T_s*np.diff(t_n, append=1)
-        # Note: No switching (e.g. d_a == 0 or d_a == 1) or simultaneous
-        # switchings (e.g d_a == d_b) lead to some zero steps.
 
-        # Array of the switching state space vectors: q = [0, q1, q2, 0]
-        q = abc2complex(q_abc.T)
+        # Flip the sequence if rising edge
+        if self.rising_edge:
+            t_steps = np.flip(t_steps)
+            q_abc = np.flipud(q_abc)
 
         # Change the carrier direction for the next call
         self.rising_edge = not self.rising_edge
 
-        # If needed, alternatively q_abc could be returned
-        return t_steps, q
+        return ((t_steps, abc2complex(q_abc.T)) if self.return_complex else
+                (t_steps, q_abc))
 
 
 # %%
@@ -154,45 +191,36 @@ class Simulation:
 
     Each simulation object has a system model object and a controller object.
 
+    Parameters
+    ----------
+    mdl : InductionMotorDrive | SynchronousMotorDrive
+        Continuous-time system model.
+    ctrl : Ctrl
+        Discrete-time controller.
+    delay : int, optional
+        Amount of computational delays. The default is 1.
+    pwm : bool, optional
+        Enable carrier comparison. The default is False.
+
     """
 
-    def __init__(self, mdl=None, ctrl=None, delay=1, enable_pwm=False,
-                 base=None, t_stop=1):
-        """
-        Parameters
-        ----------
-        mdl : InductionMotorDrive | SynchronousMotorDrive
-            Continuous-time system model.
-        ctrl : SynchronousMotorVectorCtrl | InductionMotorVectorCtrl |
-            InductionMotorVHzCtrl
-            Discrete-time controller.
-        delay : int, optional
-            Amount of computational delays. The default is 1.
-        enable_pwm : bool, optional
-            Enable carrier comparison. The default is False.
-        base : BaseValues, optional
-            Base values for plotting figures.
-        t_stop : float, optional
-            Simulation stop time. The default is 1.
-
-        """
-        # pylint: disable=too-many-arguments
+    def __init__(self, mdl=None, ctrl=None, delay=1, pwm=False):
         self.mdl = mdl
         self.ctrl = ctrl
         self.delay = Delay(delay)
-        self.base = base
-        self.t_stop = t_stop
-        if enable_pwm:
+        if pwm:
             self.pwm = CarrierCmp()
         else:
             self.pwm = zoh
 
-    def simulate(self, max_step=np.inf):
+    def simulate(self, t_stop=1, max_step=np.inf):
         """
         Solve the continuous-time model and call the discrete-time controller.
 
         Parameters
         ----------
+        t_stop : float, optional
+            Simulation stop time. The default is 1.
         max_step : float, optional
             Max step size of the solver. The default is inf.
 
@@ -203,7 +231,7 @@ class Simulation:
 
         """
         # Simulation loop
-        while self.mdl.t0 <= self.t_stop:
+        while self.mdl.t0 <= t_stop:
 
             # Run the digital controller
             T_s, d_abc_ref = self.ctrl(self.mdl)
@@ -225,7 +253,7 @@ class Simulation:
                     x0 = self.mdl.get_initial_values()
 
                     # Integrate over t_span
-                    t_span = (self.mdl.t0, self.mdl.t0+t_step)
+                    t_span = (self.mdl.t0, self.mdl.t0 + t_step)
                     sol = solve_ivp(self.mdl.f, t_span, x0, max_step=max_step)
 
                     # Set the new initial values (last points of the solution)
@@ -250,5 +278,5 @@ class Simulation:
             Name for the simulation instance. The default is 'sim'.
 
         """
-        savemat(name+'_mdl_data'+'.mat', self.mdl.data)
-        savemat(name+'_ctrl_data'+'.mat', self.ctrl.data)
+        savemat(name + '_mdl_data' + '.mat', self.mdl.data)
+        savemat(name + '_ctrl_data' + '.mat', self.ctrl.data)
